@@ -3,16 +3,23 @@ use std::path::PathBuf;
 use color_eyre::Report;
 use structopt::StructOpt;
 
-use dt_core::{config::DTConfig, syncing};
+use dt_core::{config::DTConfig, syncing, utils::default_config_path};
 
 #[derive(StructOpt, Debug)]
 #[structopt(
     global_settings(&[structopt::clap::AppSettings::ColoredHelp])
 )]
-struct Args {
+struct Opt {
     #[structopt(help = "Specifies path to config file", short, long)]
     config_path: Option<PathBuf>,
 
+    #[structopt(
+        help = "Specifies name(s) of the local group(s) to be processed",
+        short,
+        long
+    )]
+    local_name: Vec<String>,
+
     #[structopt(
         help = "Shows changes to be made without actually syncing files",
         short,
@@ -39,16 +46,36 @@ struct Args {
 }
 
 fn main() -> Result<(), Report> {
-    let opt = Args::from_args();
-    setup(opt.verbose - opt.quiet)?;
+    let opt = Opt::from_args();
+    setup(opt.verbose - opt.quiet + { opt.dry_run as i8 })?;
 
-    let config: DTConfig = DTConfig::from_path(
-        opt.config_path.unwrap_or_else(default_config_path),
-    )?;
+    log::trace!("Parsed command line: {:#?}", &opt);
+
+    let config_path = match opt.config_path {
+        Some(p) => {
+            log::debug!(
+                "Using config file from command line '{}'",
+                p.display(),
+            );
+            p
+        }
+        None => {
+            let p = default_config_path("cli.toml");
+            let p = if p.exists() {
+                p
+            } else {
+                default_config_path("config.toml")
+            };
+            log::debug!("Using inferred config file '{}'", p.display());
+            p
+        }
+    };
+
+    let config: DTConfig = DTConfig::from_path(config_path)?;
     if opt.dry_run {
-        syncing::dry_sync(&config)?;
+        syncing::dry_sync(&config, &opt.local_name)?;
     } else {
-        syncing::sync(&config)?;
+        syncing::sync(&config, &opt.local_name)?;
     }
 
     Ok(())
@@ -72,13 +99,5 @@ fn setup(verbosity: i8) -> Result<(), Report> {
     Ok(())
 }
 
-/// Gets the default config file path.
-fn default_config_path() -> PathBuf {
-    dirs::config_dir()
-        .unwrap_or_else(|| panic!("Cannot determine default config path"))
-        .join("dt")
-        .join("cli.toml")
-}
-
 // Author: Blurgy <gy@blurgy.xyz>
 // Date:   Sep 20 2021, 23:23 [CST]
